==> ws-v3.70.8-src.tar.gz: ws-v3.70-8/include/WSDprivateTimer.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDPRIVATETIMER_H
#define WSDPRIVATETIMER_H
#include <WScom.h>
#include <WSCroot.h>

class WSDprivateTimer :public WSCroot{

  protected:
    static void* _create_handler;
    long    _timer_rate;
    void   (*_work_proc)(void*);
    void*   _data;
    WSCbool _cont;
    WSCbool _timer_on;

  public:
    WSDprivateTimer();

    virtual void startTimer();
    virtual void stopTimer();

    void setWorkProc( void(*)(void*),void* );
    void setRate(long);
    void setCont(WSCbool fl);
    static WSDprivateTimer* getNewInstance();
    static void setCreateInstanceHandler(void* hd);
    void* getData();
    WSMFclassDef(WSDprivateTimer,WSCroot);
};
#endif

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/WSDprivateTimer.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSDPRIVATETIMER_H
#define WSDPRIVATETIMER_H
#include <WScom.h>
#include <WSCroot.h>

class WSDprivateTimer :public WSCroot{

  protected:
    static void* _create_handler;
    long    _timer_rate;
    void   (*_work_proc)(void*);
    void*   _data;
    WSCbool _cont;
    WSCbool _timer_on;

  public:
    WSDLEX32 WSDprivateTimer();

    WSDLEX32 virtual void startTimer();
    WSDLEX32 virtual void stopTimer();

    WSDLEX32 void setWorkProc( void(*)(void*),void* );
    WSDLEX32 void setRate(long);
    WSDLEX32 void setCont(WSCbool fl);
    WSDLEX32 static WSDprivateTimer* getNewInstance();
    WSDLEX32 static void setCreateInstanceHandler(void* hd);
    WSDLEX32 void* getData();
    WSMFclassDef(WSDprivateTimer,WSCroot);
};
#endif
